decorators Package
==================

:mod:`decorators` Package
-------------------------

.. automodule:: permission.decorators
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`classbase` Module
-----------------------

.. automodule:: permission.decorators.classbase
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`functionbase` Module
--------------------------

.. automodule:: permission.decorators.functionbase
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`methodbase` Module
------------------------

.. automodule:: permission.decorators.methodbase
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: permission.decorators.utils
    :members:
    :undoc-members:
    :show-inheritance:

